Structs
- Imported
Interface - JsModule
Spec - Specifies a JS module to be evaluated in the generated component.
Enums
- Embedding
Mode - Specifies how a given user-defined JS module gets embedded into the generated Rust crate.
- Generation
Target - Selects which WASI generation the wrapper crate targets.
Constants
- SLOT_
END_ MAGIC - Magic bytes at the end of a marker, used to validate integrity.
- SLOT_
MAGIC - Magic bytes identifying a wasm-rquickjs JS injection marker.
Functions
- create_
marker_ file - Creates a 40-byte marker file. Layout:
- generate_
dts - Generates TypeScript module definitions for a given (or default) world of a WIT package.
- generate_
dts_ with_ target - Generates TypeScript module definitions, selecting the WASI generation via
target. - generate_
wrapper_ crate - Generates a Rust wrapper crate for a combination of a WIT package and a JavaScript module.
- generate_
wrapper_ crate_ with_ target - Generates a Rust wrapper crate, selecting the WASI generation via
target. - inject_
js_ into_ component - Injects JavaScript source code into a compiled WASM component that was built with
EmbeddingMode::BinarySlot.