pub enum EmbeddingMode {
EmbedFile(Utf8PathBuf),
Composition,
BinarySlot,
}Expand description
Specifies how a given user-defined JS module gets embedded into the generated Rust crate.
Variants
EmbedFile(Utf8PathBuf)
Points to a JS module file that is going to be embedded into the generated Rust crate
Composition
The JS module is going to be fetched run-time through an imported WIT interface
BinarySlot
Embeds a small marker in the compiled WASM component.
After compilation, JS source can be injected into the marker via inject_js_into_component
without recompiling the Rust crate. The injected JS can be any size — the WASM component
is structurally rewritten to accommodate the new data.
Implementations
Sourceimpl EmbeddingMode
impl EmbeddingMode
pub fn is_binary_slot(&self) -> bool