Skip to main contentCrate wasm_rquickjs
Source - ImportedInterface
- JsModuleSpec
- Specifies a JS module to be evaluated in the generated component.
- EmbeddingMode
- Specifies how a given user-defined JS module gets embedded into the generated Rust crate.
- SLOT_END_MAGIC
- Magic bytes at the end of a marker, used to validate integrity.
- SLOT_MAGIC
- Magic bytes identifying a wasm-rquickjs JS injection marker.
- create_marker_file
- Creates a 40-byte marker file. Layout:
- generate_dts
- Generates TypeScript module definitions for a given (or default) world of a WIT package.
- generate_wrapper_crate
- Generates a Rust wrapper crate for a combination of a WIT package and a JavaScript module.
- inject_js_into_component
- Injects JavaScript source code into a compiled WASM component that was built with
EmbeddingMode::BinarySlot.